SWDEV-245531 - GLInterop: Add Buffer Interop api

Change-Id: Iddb0bb2a232e97d9071320244adc360bd7d011b5
This commit is contained in:
pghafari
2021-06-28 23:53:49 -04:00
zatwierdzone przez Payam Ghafari
rodzic 5cb9a06278
commit d0c1be0db6
+34
Wyświetl plik
@@ -4335,7 +4335,41 @@ static inline hipError_t hipUnbindTexture(
{
return hipUnbindTexture(&tex);
}
#endif // __cplusplus
/**
*-------------------------------------------------------------------------------------------------
*-------------------------------------------------------------------------------------------------
* @defgroup GL Interop
* @{
* This section describes Stream Memory Wait and Write functions of HIP runtime API.
*/
typedef unsigned int GLuint;
// Queries devices associated with GL Context.
hipError_t hipGLGetDevices(unsigned int* pHipDeviceCount, int* pHipDevices,
unsigned int hipDeviceCount, hipGLDeviceList deviceList);
// Registers a GL Buffer for interop and returns corresponding graphics resource.
hipError_t hipGraphicsGLRegisterBuffer(hipGraphicsResource** resource, GLuint buffer,
unsigned int flags);
// Maps a graphics resource for hip access.
hipError_t hipGraphicsMapResources(int count, hipGraphicsResource_t* resources,
hipStream_t stream __dparm(0) );
// Gets device accessible address of a graphics resource.
hipError_t hipGraphicsResourceGetMappedPointer(void** devPtr, size_t* size,
hipGraphicsResource_t resource);
// Unmaps a graphics resource for hip access.
hipError_t hipGraphicsUnmapResources(int count, hipGraphicsResource_t* resources,
hipStream_t stream __dparm(0));
// Unregisters a graphics resource.
hipError_t hipGraphicsUnregisterResource(hipGraphicsResource_t resource);
// doxygen end GL Interop
/**
* @}
*/
#ifdef __GNUC__
#pragma GCC visibility pop
#endif